<?php

namespace Teknisa\SM\Controller;

use Teknisa\SM\Controller\SMCrud;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\Sm00015004AgendamentoDeRecursoService;

class Sm00015004AgendamentoDeRecursoController extends SMCrud {
    
    protected $dataSourceName = "fct_agendrecursocont_widget";
    protected $agendamentoService;

    public function __construct($crudService, $environment, Sm00015004AgendamentoDeRecursoService $agendamentoService) {
        parent::__construct($crudService, $environment);
        $this->agendamentoService = $agendamentoService;
    }
    
    public function salvarAgendamentosPendentes(Request $request, Response $response) {
        try {
            $nrseqorcamento  = null;
            $nrseqcontrato   = null;
            $nritemocontrato = null;
            $quantidade      = null;
            $nritemorcamento = null;
            
            $row = $request->getRow();
            if($row["ROTINA"] == "CONTRATO"){
                $nrseqcontrato   = $row["NRSEQCONTRATO"];
                $nritemocontrato = $row["NRITEMOCONTRATO"];
                $quantidade      = $row["QUANTIDADE"];
                $situacao        = $row["IDSITUACAOCONTRATO"];
            } else {
                $nrseqorcamento  = $row["NRSEQORCAMENTO"];
                $quantidade      = $row["QUANTIDADE"];
                $nritemorcamento = $row["NRITEMORCAMENTO"];
                $situacao        = $row["IDSITUACAOORCAMENTO"];
            }
            
            $nrorg      = $this->environment->getNrOrg();
            $cdoperador = $this->environment->getCdOperador();
            
            $this->agendamentoService->salvarAgendamentosPendentes($nrseqcontrato, $nrseqorcamento, $nrorg, $cdoperador, $nritemocontrato, $nritemorcamento, $quantidade, $situacao);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function solicitarSubstituicaoRecurso(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $recursos      = $row["RECURSOS"];
            $justificativa = $row["JUSTIFICATIVA"];
            
            $cdoperador = $this->environment->getCdOperador();
            $nrorg = $this->environment->getNrOrg();
            
            $this->agendamentoService->solicitarSubstituicaoRecurso($recursos, $justificativa, $cdoperador, $nrorg);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function solicitarCoberturaRecurso(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $recursos      = $row["RECURSOS"];
            $justificativa = $row["JUSTIFICATIVA"];
            
            $cdoperador = $this->environment->getCdOperador();
            $nrorg = $this->environment->getNrOrg();
            
            $this->agendamentoService->solicitarCoberturaRecurso($recursos, $justificativa, $cdoperador, $nrorg);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function salvarSubstituicaoRecurso(Request\Row $request, Response $response) {
        try {
            $row = $request->getRow();
            $nragendrecursocont  = $row["NRAGENDRECURSOCONT"];
            $nrrecursosagendcont = $row["NRRECURSOSAGENDCONT"];
            $idtprecursoante     = $row["IDTPRECURSOANTE"];
            $chaveante           = $row["CHAVEANTE"];
            $cdempresaante       = $row["CDEMPRESAANTE"];
            $idtprecurso         = $row["IDTPRECURSO"];
            $chave               = $row["CHAVE"];
            $cdempresa           = $row["CDEMPRESA"];
            $dataSubstituicao    = $row["DATASUBSTITUICAO"];
            $justificativa       = $row["JUSTIFICATIVA"];
            $idescala            = $row["IDESCALATRAB"];
            $hrjornada           = $row["HRJORNADADIARIA"];
            $hrdescanso          = $row["HRDESCANSO"];
            $hrintervalo          = $row["HRINTERVALO"];
            
            $cdoperador = $this->environment->getCdOperador();
            $nrorg = $this->environment->getNrOrg();
            
            $this->agendamentoService->salvarSubstituicaoRecurso($nragendrecursocont, $nrrecursosagendcont, $idtprecursoante, $chaveante, $cdempresaante, $idtprecurso, $chave, $cdempresa, $dataSubstituicao, $justificativa, $cdoperador, $nrorg, $idescala, $hrjornada, $hrdescanso, $hrintervalo);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    /**
     * 
     */
    public function salvarCoberturaRecurso(Request\Row $request, Response $response) {
        try {
            $row                  = $request->getRow();
            $nragendrecursocont   = $row["NRAGENDRECURSOCONT"];
            $nrrecursosagendcont  = $row["NRRECURSOSAGENDCONT"];
            $idtprecursoante      = $row["IDTPRECURSOANTE"];
            $chaveante            = $row["CHAVEANTE"];
            $cdempresaante        = $row["CDEMPRESAANTE"];
            $idtprecurso          = $row["IDTPRECURSO"];
            $chave                = $row["CHAVE"];
            $cdempresa            = $row["CDEMPRESA"];
            $dataInicialCobertura = $row["DATAINICIAL"];
            $dataFinalCobertura   = $row["DATAFINAL"];
            $justificativa        = $row["JUSTIFICATIVA"];
            $idescala             = $row["IDESCALATRAB"];
            $hrjornada            = $row["HRJORNADADIARIA"];
            $hrdescanso           = $row["HRDESCANSO"];
            $hrintervalo           = $row["HRINTERVALO"];
            
            $cdoperador = $this->environment->getCdOperador();
            $nrorg = $this->environment->getNrOrg();
            
            $this->agendamentoService->salvarCoberturaRecurso($nragendrecursocont, $nrrecursosagendcont, $idtprecursoante, $chaveante, $cdempresaante, $idtprecurso, $chave, $cdempresa, $dataInicialCobertura, $dataFinalCobertura, $justificativa, $cdoperador, $nrorg, $idescala, $hrjornada, $hrdescanso, $hrintervalo);
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function atualizarAgendamentoPendente(Resquest\Row $request, Response $response){
        try{
            $row = $request->getRow();
            $idpendencia     = $row["IDPENDECIA"]; 
            $nritemocontrato = $row["NRITEMOCONTRATO"]; 
            $nrseqcontrato   = $row["NRSEQCONTRATO"]; 
            $nrseqorcamento  = $row["NRSEQORCAMENTO"]; 
            $nritemorcamento = $row["NRITEMORCAMENTO"]; 
            $nrorg = $this->environment->getNrorg();    
            $this->agendamentoService->atualizarAgendamentoPendente($idpendencia, $nritemocontrato, $nrseqcontrato, $nrseqorcamento, $nritemorcamento, $nrorg);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}

?>